==> videorbits-2.201.tgz: videorbits-2.201/scripts/estcement.pl <==
#!/usr/bin/perl

use integer; # all arithmetic in this entire universe shall now be integer,
             # therefore you cannot have a mixture of integer and float arith.

$Ps = sprintf("Parameters_pairwise.txt"); # cumulative, plurality of parameters

if ($#ARGV < 0) {
  printf("Use: estcement.pl v???.jpg # or use gash\n");
  printf("     estcement.pl also autodetects jpg or ppm\n");
  printf("     This will run: estpairwise.pl, then\n");
  printf("                    pintegrate, then\n");
  printf("                    pchirp2nocrop.pl, then\n");
  printf("                    cement\n");
  printf("     to produce a file called cemented.pnm\n");
  die "     ERROR: YOU MUST SPECIFY SOME FILENAMES TO BE CEMENTED$!\n";
}

$commandstr1 = "estpairwise.pl @ARGV";
printf("estcement.pl: about to run $commandstr1\n");
system($commandstr1);

$numberoffiles = $#ARGV+1;
$middle = $numberoffiles/2;
$commandstr2 = "pintegrate parameters_pairwise.txt $middle > Parameters_pairwise.txt ";
printf("estcement.pl: about to run $commandstr2\n");
system($commandstr2);

$commandstr3 = "pchirp2nocrop.pl @ARGV";
printf("estcement.pl: about to run $commandstr3\n");
system($commandstr3);

# now cement v???d.pnm or whatever:
$newfilenames = "";
for ($counter=0; $counter<=$#ARGV+1-1; $counter++) {
  # $#ARGV is -1 if no arguments given; is 0 if 1 argument given, etc...
  $filein = $ARGV[$counter];
  $periodposition = rindex($filein,"."); # right index, period from right
  $postfix = substr($filein,$periodposition+1,3); # 2 char, e.g. JP or jp
  $postfix =~ tr/[A-Z]/[a-z]/;
  $fileout = substr($filein,0,$periodposition); # before period
  $fileout = $fileout."d".".pnm"; 
  printf("fileout is %s\n", $fileout);
  $newfilenames = $newfilenames." ".$fileout;
}
$commandstr4 = "cement cemented.pnm $newfilenames";
printf("estcement.pl: about to run $commandstr4\n");
system($commandstr4);

==> videorbits-2.205.tgz: videorbits-2.205/scripts/estcement.pl <==
#!/usr/bin/perl

use integer; # all arithmetic in this entire universe shall now be integer,
             # therefore you cannot have a mixture of integer and float arith.

$Ps = sprintf("Parameters_pairwise.txt"); # cumulative, plurality of parameters

if ($#ARGV < 0) {
  printf("Use: estcement.pl v???.jpg # or use gash\n");
  printf("     estcement.pl also autodetects jpg or ppm\n");
  printf("     This will run: estpairwise.pl, then\n");
  printf("                    pintegrate, then\n");
  printf("                    pchirp2nocrop.pl, then\n");
  printf("                    cement\n");
  printf("     to produce a file called cemented.pnm\n");
  die "     ERROR: YOU MUST SPECIFY SOME FILENAMES TO BE CEMENTED$!\n";
}

$commandstr1 = "estpairwise.pl @ARGV";
printf("estcement.pl: about to run $commandstr1\n");
system($commandstr1);

$numberoffiles = $#ARGV+1;
$middle = $numberoffiles/2;
$commandstr2 = "pintegrate parameters_pairwise.txt $middle > Parameters_pairwise.txt ";
printf("estcement.pl: about to run $commandstr2\n");
system($commandstr2);

$commandstr3 = "pchirp2nocrop.pl -png @ARGV";
printf("estcement.pl: about to run $commandstr3\n");
system($commandstr3);

# now cement v???d.pnm or whatever:
$newfilenames = "";
for ($counter=0; $counter<=$#ARGV+1-1; $counter++) {
  # $#ARGV is -1 if no arguments given; is 0 if 1 argument given, etc...
  $filein = $ARGV[$counter];
  $periodposition = rindex($filein,"."); # right index, period from right
  $postfix = substr($filein,$periodposition+1,3); # 2 char, e.g. JP or jp
  $postfix =~ tr/[A-Z]/[a-z]/;
  $fileout = substr($filein,0,$periodposition); # before period
  $fileout = $fileout."d".".png"; 
  printf("fileout is %s\n", $fileout);
  $newfilenames = $newfilenames." ".$fileout;
}
$commandstr4 = "cement -certainted cemented.pnm $newfilenames";
printf("estcement.pl: about to run $commandstr4\n");
system($commandstr4);
